@@ -100,7 +100,7 @@ class BaseLog:
 
     @staticmethod
     def date_log_time():
-        return datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+        return datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")[:-3]
 
     @staticmethod
     def find_caller():
